==> haskell-contravariant-1.4-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-contravariant/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.4
id: contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
key: contr_KM4fAXZBaqx6OO468wTyg6
license: BSD3
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors
category: Control, Data
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Functor.Contravariant Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-1.4
hs-libraries: HScontravariant-1.4-KM4fAXZBaqx6OO468wTyg6
depends:
    StateVar-1.1.0.3-dfbaaa5b80efc1d36dff08b16817e21d
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-1.4-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-contravariant/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.4
id: contravariant-1.4-1b3716257293d15c38698a7852cba3ac
key: contr_0AUr50yDVwNB7DInKN0aLv
license: BSD3
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors
category: Control, Data
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Functor.Contravariant Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-1.4
hs-libraries: HScontravariant-1.4-0AUr50yDVwNB7DInKN0aLv
depends:
    StateVar-1.1.0.4-fc65b0726880e394d3716252d743e7fc
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-255c5771d2d826ed3cb8a752061ff594
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
